CA12_Cl02.html
open | /cms/logout/ |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Users |
clickAndWait | link=Añadir usuario |
type | id_username | nuevousuario
type | id_password1 | 1234
type | id_password2 | 1234
clickAndWait | _save |
clickAndWait | link=Usuarios |
type | searchbar | nuevousuario
clickAndWait | //input[@value='Buscar'] |
click | action-toggle |
select | action | label=Eliminar usuarios seleccionado/s
clickAndWait | index |
verifyTextPresent | exact:¿Está seguro de que quiere borrar los usuario seleccionados? Los siguientes objetos y sus elementos relacionados serán eliminados: |
verifyTextPresent | exact:Usuario: nuevousuario |
clickAndWait | //input[@value='Sí, estoy seguro'] |
verifyTextPresent | Eliminado/s 1 usuario satisfactoriamente. |
clickAndWait | link=Terminar sesión |